@@ -416,12 +416,13 @@ class Session:
             return dict(zip(probe_letters, csv_paths))
         return {}
     
-    @cached_property
+    @property
     def platform_json(self) -> PlatformJson:
         """Platform D1 json on npexp."""
-        pj = PlatformJson(self.npexp_path)
-        self.fix_platform_json(pj)
-        return pj
+        with contextlib.suppress(AttributeError):
+            return self._platform_json
+        self._platform_json = PlatformJson(self.npexp_path)
+        return self.platform_json
     
     def fix_platform_json(self, path_or_obj: Optional[pathlib.Path | PlatformJson] = None):
         if not path_or_obj:
@@ -429,9 +430,8 @@ class Session:
         if isinstance(path_or_obj, pathlib.Path):
             path_or_obj = PlatformJson(path_or_obj)
         pj = path_or_obj
-
         update_platform_json_fields(pj, self)
-
+        # TODO get files dict, fetch files
     
     @cached_property
     def experiment_start(self) -> datetime.datetime:
